#ifndef __CUTTEST__UTILS_H__
#define __CUTTEST__UTILS_H__

#include <glib.h>

const gchar *cuttest_get_base_dir(void);

#endif
